/*
 * Bootchart -- Boot Process Visualization
 *
 * Copyright (C) 2004  Ziga Mahkovec <ziga.mahkovec@klika.si>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package org.bootchart.renderer;

import java.awt.image.RenderedImage;
import java.io.IOException;
import java.io.OutputStream;
import java.lang.reflect.Method;
import java.util.Properties;
import java.util.logging.Logger;

import org.bootchart.common.BootStats;


/**
 * PNGRenderer renders the boot chart as a PNG image.
 */
public class PNGRenderer extends ImageRenderer {
	private static final Logger log = Logger.getLogger(PNGRenderer.class.getName());
	
	/*
	 * inherit javadoc
	 */
	public void render(Properties headers, BootStats bootStats, OutputStream os)
		throws IOException {
		
	 	super.render(headers, bootStats, null);
	 	
		/*
		 * Encode PNG image.
		 */
		log.fine("Writing image");
		/*
		 * Call ImageIO.write(img, "png", os) using the reflection API as
		 * some free JRE implementations lack the class.
		 */
		try {
			Class imageioClass = Class.forName("javax.imageio.ImageIO");
			Class[] params =
				{ RenderedImage.class, String.class, OutputStream.class };
			Method writeMethod = imageioClass.getMethod("write", params);
			writeMethod.invoke(null, new Object[]{img, "png", os});
		} catch (Exception e) {
			// ImageIO.write() not implemented
			throw new RuntimeException(e);
		}
	}
	
	/*
	 * inherit javadoc
	 */
	public String getFileSuffix() {
		return "png";
	}
}
